@@ -6,7 +6,10 @@ import requests as requests
 from dotenv import load_dotenv
 
 from cloudtipsadp.constants import (BASE_URL, BASE_URL_API,
-                                        BASE_URL_SANDBOX)
+                                        BASE_URL_SANDBOX, M_BAD_CONNECT,
+                                        M_BASE_IMPLEMENTED,
+                                        BASE_URL_API_SANDBOX, API_VERSION,
+                                        HEADERS_REQUEST)
 
 load_dotenv()
 
@@ -38,46 +41,33 @@ class ConnectData:
                     refresh_token=tkn['refresh_token'])
 
 
-def my_name():
-    """Получить имя текущего метода."""
-    stack = traceback.extract_stack()
-    print('Print from {}'.format(stack[-2][2]))
-
-
 class BaseClient:
     token: Token
     base_url: str = BASE_URL
-    headers: dict = {"Content-Type": "application/x-www-form-urlencoded"}
     auth_url = 'connect/token'
 
     def valid(self, response):
         if response.ok:
             self.token: Token = response.json()
             return response
-        else:
-            text = f'{response.status_code}: {response.reason} connection ' \
-                   f'to the service.'
-            raise ConfigurationError(text)
-
-            # raise GeneratorExit(response.reason, response.status_code)
+        return None
 
     def connect(self):
-        # try:
         response = self.auth()
         self.valid(response)
-        # except Exception as e:
-        #     raise NotImplementedError(e)
 
     @staticmethod
-    def api(endpoint: str):
+    def api(endpoints: list, base_url=BASE_URL_API):
         """Вернёт правильный URL для запроса к API."""
-        return urljoin(BASE_URL_API, endpoint)
+        endpoints.insert(0, API_VERSION)
+        path = '/'.join(x for x in endpoints)
+        return urljoin(base_url, path)
 
     @classmethod
     def auth(cls):
         """Авторизоваться в системе."""
         return requests.post(cls.base_url, data=ConnectData.get(),
-                             headers=cls.headers)
+                             headers=HEADERS_REQUEST)
 
     def refresh_token(self):
         """
@@ -85,7 +75,13 @@ class BaseClient:
         Для получения нового access_token необходимо использовать
         refresh_token полученный при авторизации.
         """
-        raise NotImplementedError('Base class method not implemented.')
+        raise NotImplementedError(M_BASE_IMPLEMENTED)
+
+    # def get_headers(self):
+    #     """
+    #     Получить заголовки для API соединения.
+    #     """
+    #     raise NotImplementedError(M_BASE_IMPLEMENTED)
 
 
 class ProductClient(BaseClient):
@@ -95,7 +91,11 @@ class ProductClient(BaseClient):
     def refresh_token(self):
         return requests.post(self.base_url,
                              data=ConnectData.refresh(self.token),
-                             headers=self.headers)
+                             headers=HEADERS_REQUEST)
+
+    @staticmethod
+    def api(endpoints: list, base_url=BASE_URL_API):
+        pass
 
 
 class SandboxClient(BaseClient):
@@ -105,9 +105,12 @@ class SandboxClient(BaseClient):
     def refresh_token(self):
         response = requests.post(self.base_url,
                                  data=ConnectData.refresh(self.token),
-                                 headers=self.headers)
+                                 headers=HEADERS_REQUEST)
         self.valid(response)
 
+    def api(self, endpoints: list, base_url=BASE_URL_API_SANDBOX):
+        return super(SandboxClient, self).api(endpoints, base_url)
+
 
 class Connect:
     """Singleton."""
@@ -128,13 +131,25 @@ class Connect:
 
     @classmethod
     def get_token(cls):
-        return (f'{cls.client.token["token_type"]}'
-                f' {cls.client.token["access_token"]}')
+        try:
+            return (f'{cls.client.token["token_type"]}'
+                    f' {cls.client.token["access_token"]}')
+        except AttributeError:
+            print(M_BAD_CONNECT)
 
     def refresh_token(self):
-        self.client.refresh_token()
-        return (f'{self.client.token["token_type"]}'
-                f' {self.client.token["access_token"]}')
+        try:
+            self.client.refresh_token()
+        except AttributeError:
+            print(M_BAD_CONNECT)
+        else:
+            return (f'{self.client.token["token_type"]}'
+                    f' {self.client.token["access_token"]}')
+
+    @classmethod
+    def get_headers(cls):
+        return {"Authorization": f"{cls.get_token()}",
+                "Content-Type": "application/json"}
 
 
 if __name__ == '__main__':
@@ -142,23 +157,13 @@ if __name__ == '__main__':
     # нужно смотреть в дебагере. Run и Debug возвращают разные значения.
     # ProductClient - будет доступен с данными для production, когда менеджер
     # выдаст новые логин и пароль
-    # client = ProductClient()
-    connect = Connect()
-    # connect2 = Connect(SandboxClient())
-    token = connect.get_token()
-    print(f'TOKEN::{token[-5:]}')
-    #
-    # refresh_token = connect.refresh_token()
-    # print(f'REFRESH TOKEN::{refresh_token[-5:]}')
-    # token2 = connect2.get_token()
-    # print(f'TOKEN2::{token2[-5:]}')
-    #
-    # refresh_token2 = connect.refresh_token()
-    # print(f'REFRESH TOKEN::{refresh_token2[-5:]}')
-    # token3 = connect2.get_token()
-    #
-    # print(f'TOKEN3::{token3[-5:]}')
-    # token2 = connect2.get_token()
-    # print(f'TOKEN2::{token2[-5:]}')
+    # Подключение к Production service
+    # connect = Connect()
+    # # Получить токен
     # token = connect.get_token()
-    # print(f'TOKEN::{token[-5:]}')
+
+    # Подключение к Sandbox service
+    connect = Connect(SandboxClient())
+    # Получить токен
+    token = connect.get_token()
+    print(token)
