@@ -1,18 +1,19 @@
 __all__ = [
-    'CLOUDTIPS_API_TOKEN',
-    'AUTH_URL',
     'BASE_URL',
     'BASE_URL_API',
-    'CLOUDTIPS_ID_COMPANY',
     'BASE_URL_SANDBOX',
     'BASE_URL_API_SANDBOX',
-    'AUTH_URL_SANDBOX',
+    'M_BAD_CONNECT',
+    'M_BASE_IMPLEMENTED',
+    'API_VERSION',
+    'HEADERS_REQUEST',
 ]
 BASE_URL = 'https://identity.cloudtips.ru'
 BASE_URL_SANDBOX = 'https://identity-sandbox.cloudtips.ru'
 BASE_URL_API = 'https://api.cloudtips.ru/api'
 BASE_URL_API_SANDBOX = 'https://api-sandbox.cloudtips.ru'
-CLOUDTIPS_API_TOKEN = 'wercvbhgfhw345345'
-AUTH_URL = f'{BASE_URL}/connect/token'
-AUTH_URL_SANDBOX = f'{BASE_URL_SANDBOX}/connect/token'
-CLOUDTIPS_ID_COMPANY = 'sdfrt546456hfgh'
+M_BAD_CONNECT = 'No service connection.'
+M_BASE_IMPLEMENTED = 'Base class method not implemented.'
+API_VERSION = 'api'
+HEADERS_REQUEST = {"Content-Type": "application/x-www-form-urlencoded"}
+
